### Name: logLik.frontier
### Title: Extract Log-Likelihood Value
### Aliases: logLik.frontier
### Keywords: models

### ** Examples

   # example included in FRONTIER 4.1
   data( front41Data )
   front41Data$logOutput  <- log( front41Data$output )
   front41Data$logCapital <- log( front41Data$capital )
   front41Data$logLabour  <- log( front41Data$labour )

   # SFA estimation with starting values obtained from a grid search
   sfa <- frontier( yName = "logOutput",
      xNames = c( "logCapital", "logLabour" ), data = front41Data )
   logLik( sfa, which = "ols" )
   logLik( sfa, which = "grid" )
   logLik( sfa )

   # SFA estimation with starting values provided by the user
   sfa2 <- frontier( yName = "logOutput",
      xNames = c( "logCapital", "logLabour" ), data = front41Data,
      startVal = 0.9 * coef( sfa ) )
   logLik( sfa2, which = "ols" )
   logLik( sfa2, which = "start" )
   logLik( sfa2 )

   # evaluate log likelihood function for a user-provided parameter vector
   logLik( sfa, newParam = 0.9 * coef( sfa ) )
      # equal to  logLik( sfa2, which = "start" )

   # log likelihood function for different values of gamma
   plot( t( sapply( seq( 0.05, 0.95, 0.05 ), function(x) c( x,
      logLik( sfa, newParam = c( coef( sfa )[1:4], x ) ) ) ) ) )



